# Table of Contents

- [best-practices-for-integration-api](<./best-practices-for-integration-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Best Practices for the Integration API](<./Best-Practices-for-the-Integration-API.md>)
  - [Overview](<./Best-Practices-for-the-Integration-API/Overview.md>)
  - [Use the UI](<./Best-Practices-for-the-Integration-API/Use-the-UI.md>)
  - [Check Scope Before Firing Test Runs](<./Best-Practices-for-the-Integration-API/Check-Scope-Before-Firing-Test-Runs.md>)
  - [Adhere to Proper Processor Versioning Convention](<./Best-Practices-for-the-Integration-API/Adhere-to-Proper-Processor-Versioning-Convention.md>)
  - [Use Webhooks](<./Best-Practices-for-the-Integration-API/Use-Webhooks.md>)
  - [Leverage Deletion Scope](<./Best-Practices-for-the-Integration-API/Leverage-Deletion-Scope.md>)
  - [Cover All Edge Cases to Eliminate Warnings and Errors](<./Best-Practices-for-the-Integration-API/Cover-All-Edge-Cases-to-Eliminate-Warnings-and-Errors.md>)
  - [Configuring Automated Nightly Runs](<./Best-Practices-for-the-Integration-API/Configuring-Automated-Nightly-Runs.md>)
